@@ -84,7 +84,7 @@ class RequestMiddleware:
         self._raised_exception = True
 
         traceback_object = exception.__traceback__
-        formatted_traceback = traceback.format_tb(traceback_object)
+        formatted_traceback = "".join(traceback.format_tb(traceback_object))
         self.bind_user_id(request),
         signals.bind_extra_request_failed_metadata.send(
             sender=self.__class__, request=request, logger=logger, exception=exception
